import {select, 
        csv, 
        scaleLinear, 
        scaleTime,
        max, 
        extent,
        scalePoint,
        axisLeft,
        axisBottom,
        area,
        curveBasis
       } from 'd3';

const svg=select('svg');
svg.style('background-color','white');
const height=parseFloat(svg.attr('height'));
const width= +svg.attr('width');//+ Uniary operator to convert to Float


const render= data=>{
  const title="A Month in San Fransisco";
  const xValue= d=>d.Date;
  const xAxisLabel="Time";
  const yValue= d=>d['Mean.TemperatureF'];
  const yAxisLabel="Temperature";
  const circleRadius=5;
  const margin=	{top:50,bottom:100,left:150,right:40};
  const innerWidth= width-margin.left-margin.right;
  const innerHeight= height-margin.top-margin.bottom;
  
  const xScale= scaleLinear()
  	.domain(extent(data,xValue))
  	.range([0,innerWidth]);
  
  const yScale=scaleLinear()
  	.domain(extent(data,yValue))
  	.range([innerHeight,0])
  	.nice();
  
  const yAxis= axisLeft(yScale)
  	.tickSize(-innerWidth)
  	.tickPadding(10);
  const xAxis= axisBottom(xScale)
  	.tickSize(-innerHeight)
  	.tickPadding(15);
  
  const g= svg.append('g')
  	.attr('transform',`translate(${margin.left},${margin.top})`);
  //yAxis(g.append('g'));
  //xAxis(g.append('g'));
  const yAxisG=g.append('g').call(yAxis);
  yAxisG.select('.domain').remove();
  yAxisG.append('text')
  	.attr('class','axis-label')
    .attr('y',-80)
  	.attr('x',-innerHeight/2)
    .attr('fill','black')
  	.attr('transform',`rotate(-90)`)
  	.attr('text-anchor','middle')
    .text(yAxisLabel);
  const xAxisG=g.append('g').call(xAxis)//setting up X-Axis
  	.attr('transform',`translate(0,${innerHeight})`)// to bring it down
  xAxisG.select('.domain').remove()
  xAxisG.append('text')
  	.attr('class','axis-label')
    .attr('y',80)
  	.attr('x',innerWidth/2)
    .attr('fill','black')
    .text(xAxisLabel);
  
  const areaGenerator= area()
  	.x(d=>xScale(xValue(d)))
  	.y0(innerHeight)
  	.y1(d=>yScale(yValue(d)))
  	.curve(curveBasis);
  g.append('path')
  	.attr('class','line-path')
  	.attr('d',areaGenerator(data));
  
  g.append('text')
  	.attr('y',-10)
  	.text(title);
}
csv('data.csv')
  .then(data=> {
    data.forEach(d=>	{
      d['Max.TemperatureF']=	+d['Max.TemperatureF'];
      d['Min.TemperatureF']=	+d['Min.TemperatureF'];
      d['Mean.TemperatureF']=	+d['Mean.TemperatureF'];
      d.Date=new Date(d.Date).getDate();
  });
  console.log(data)
  render(data);
});
